public inbox for gdb-patches@sourceware.org
 help / color / mirror / Atom feed
* [PATCH] Handle 64-bit Solaris/x86 ld.so.1
@ 2018-09-17 14:24 Rainer Orth
  2018-09-17 18:37 ` Joel Brobecker
  0 siblings, 1 reply; 3+ messages in thread
From: Rainer Orth @ 2018-09-17 14:24 UTC (permalink / raw)
  To: gdb-patches

[-- Attachment #1: Type: text/plain, Size: 461 bytes --]

The next patch from the solaris-userland github repo
(007-solib-svr4.patch) is equally trivial, creating partity between
Solaris/SPARC and x86.

Tested on amd64-pc-solaris2.11, ok for master?

	Rainer

-- 
-----------------------------------------------------------------------------
Rainer Orth, Center for Biotechnology, Bielefeld University


2018-06-27  Rainer Orth  <ro@CeBiTec.Uni-Bielefeld.DE>

	* solib-svr4.c (svr4_same_1): Also handle amd64 ld.so.1.


[-- Warning: decoded text below may be mangled, UTF-8 assumed --]
[-- Attachment #2: solx64-ld.so.patch --]
[-- Type: text/x-patch, Size: 796 bytes --]

# HG changeset patch
# Parent  24bcd64cb0c1824acde40384274e58fa9bf13438
Handle 64-bit Solaris/x86 ld.so.1

diff --git a/gdb/solib-svr4.c b/gdb/solib-svr4.c
--- a/gdb/solib-svr4.c
+++ b/gdb/solib-svr4.c
@@ -153,8 +153,12 @@ svr4_same_1 (const char *gdb_so_name, co
       && strcmp (inferior_so_name, "/lib/ld.so.1") == 0)
     return 1;
 
   /* Similarly, we observed the same issue with sparc64, but with
      different locations.  */
+  if (strcmp (gdb_so_name, "/usr/lib/amd64/ld.so.1") == 0
+      && strcmp (inferior_so_name, "/lib/amd64/ld.so.1") == 0)
+    return 1;
+
   if (strcmp (gdb_so_name, "/usr/lib/sparcv9/ld.so.1") == 0
       && strcmp (inferior_so_name, "/lib/sparcv9/ld.so.1") == 0)
     return 1;

^ permalink raw reply	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2018-09-19  9:11 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
@@ -153,8 +153,12 @@ svr4_same_1 (const char *gdb_so_name, co
     return 1;
 
-  /* Similarly, we observed the same issue with sparc64, but with
+  /* Similarly, we observed the same issue with amd64 and sparcv9, but with
      different locations.  */
2018-09-17 14:24 [PATCH] Handle 64-bit Solaris/x86 ld.so.1 Rainer Orth
2018-09-17 18:37 ` Joel Brobecker
2018-09-19  9:11   ` Rainer Orth

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).